import PropTypes from 'prop-types';
import React, { useState, useEffect } from 'react';
import Context from './Context'; //for rtl support

import { create } from 'jss';
import rtl from 'jss-rtl';
import { StylesProvider, jssPreset } from '@material-ui/core/styles'; // Configure JSS

var jss = create({
  plugins: [].concat(jssPreset().plugins, [rtl()])
});

var Provider = function Provider(_ref) {
  var children = _ref.children,
      _ref$persistKey = _ref.persistKey,
      persistKey = _ref$persistKey === void 0 ? 'theme' : _ref$persistKey,
      appConfig = _ref.appConfig;

  var _ref2 = appConfig || {},
      themeConfig = _ref2.theme;

  var _ref3 = themeConfig || {},
      defaultThemeID = _ref3.defaultThemeID,
      defaultType = _ref3.defaultType,
      defaultIsRTL = _ref3.defaultIsRTL;

  var _useState = useState(defaultThemeID),
      themeID = _useState[0],
      setThemeID = _useState[1];

  var _useState2 = useState(defaultType),
      type = _useState2[0],
      setType = _useState2[1];

  var _useState3 = useState(defaultIsRTL),
      isRTL = _useState3[0],
      setIsRTL = _useState3[1];

  var themeIDKey = persistKey + ":themeID";
  var typeKey = persistKey + ":type";
  var isRTLKey = persistKey + ":isRTL";

  var toggleThis = function toggleThis(mode) {
    if (mode === 'isRTL') setIsRTL(!isRTL);
  };

  useEffect(function () {
    var persistThemeID = localStorage.getItem(themeIDKey);
    var persistType = localStorage.getItem(typeKey);
    var persistIsRTL = localStorage.getItem(isRTLKey);

    if (persistThemeID) {
      setThemeID(persistThemeID);
    }

    if (persistType) {
      setType(persistType);
    }

    if (persistIsRTL) {
      //have to convert the stored string back to boolean
      setIsRTL(persistIsRTL === 'true' ? true : false);
    }
  }, [themeIDKey, typeKey, isRTLKey]);
  useEffect(function () {
    try {
      localStorage.setItem(themeIDKey, themeID);
    } catch (error) {
      console.warn(error);
    }
  }, [themeID, themeIDKey]);
  useEffect(function () {
    try {
      localStorage.setItem(typeKey, type);
    } catch (error) {
      console.warn(error);
    }
  }, [type, typeKey]);
  useEffect(function () {
    try {
      localStorage.setItem(isRTLKey, isRTL);
    } catch (error) {
      console.warn(error);
    }
  }, [isRTL, isRTLKey]);
  return /*#__PURE__*/React.createElement(Context.Provider, {
    value: {
      themeID,
      type,
      setThemeID,
      setType,
      isRTL,
      toggleThis
    }
  }, /*#__PURE__*/React.createElement(StylesProvider, {
    jss: jss
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      direction: isRTL ? 'rtl' : 'ltr'
    }
  }, children)));
};

Provider.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.any
} : {};
export default Provider;